@@ -25,15 +25,11 @@ static void pe_idle_dtor(pe_watcher *ev) {
 }
 
 static char *pe_idle_start(pe_watcher *ev, int repeating) {
-    double now;
-    double min,max;
+    NV now;
+    NV min,max;
     pe_idle *ip = (pe_idle*) ev;
     if (!ev->callback)
 	return "without callback";
-    if (SvOK(ip->min_interval) || SvOK(ip->max_interval))
-	WaCBTIME_on(ev);
-    else
-	WaCBTIME_off(ev);
     if (!repeating) ev->cbtime = NVtime();
     now = WaHARD(ev)? ev->cbtime : NVtime();
     if (sv_2interval("min", ip->min_interval, &min)) {
@@ -54,8 +50,8 @@ static char *pe_idle_start(pe_watcher *ev, int repeating) {
 }
 
 static void pe_idle_alarm(pe_watcher *wa, pe_timeable *_ignore) {
-    double now = NVtime();
-    double min,max,left;
+    NV now = NVtime();
+    NV min,max,left;
     pe_idle *ip = (pe_idle*) wa;
     pe_timeable_stop(&ip->tm);
     if (sv_2interval("min", ip->min_interval, &min)) {
